@@ -9,8 +9,11 @@ When it comes to importing the values, import them from ``qartez.settings`` modu
 
 ``CHANGEFREQ``: Valid changefreq values according to the specs http://www.sitemaps.org/protocol.html
 """
-
-__all__ = ('PREPEND_LOC_URL_WITH_SITE_URL', 'PREPEND_IMAGE_LOC_URL_WITH_SITE_URL', 'CHANGEFREQ')
+__title__ = 'qartez'
+__version__ = '0.4'
+__build__ = 0x000004
+__author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
+__all__ = ('PREPEND_LOC_URL_WITH_SITE_URL', 'PREPEND_IMAGE_LOC_URL_WITH_SITE_URL', 'CHANGEFREQ', 'DEBUG')
 
 from qartez.conf import get_setting
 
